added new api hipHccModuleLaunchKernel

1. hipHccModuleLaunchKernel is same as hipModuleLaunchKernel with OpenCL workitem model
2. Added copy right
3. Fixed header naming

Change-Id: I6a7c35a3566e2f8d3f5056613e34193775d4b236
This commit is contained in:
Aditya Atluri
2017-03-31 12:11:34 -05:00
والد 071f19521c
کامیت b9091ba818
30فایلهای تغییر یافته به همراه1138 افزوده شده و 91 حذف شده
@@ -1,5 +1,5 @@
/*
Copyright (c) 2015-2016 Advanced Micro Devices, Inc. All rights reserved.
Copyright (c) 2015 - present Advanced Micro Devices, Inc. All rights reserved.
Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
@@ -27,4 +27,3 @@ extern "C" __global__ void hello_world(hipLaunchParm lp, float *a, float *b)
int tx = hipThreadIdx_x;
b[tx] = a[tx];
}